@@ -2,11 +2,11 @@ use strict;
 use warnings FATAL => 'all';
 
 package WWW::Mechanize::Cached;
-$WWW::Mechanize::Cached::VERSION = '1.45';
+$WWW::Mechanize::Cached::VERSION = '1.46';
 use 5.006;
 
 use Class::Load 'try_load_class';
-use Moo;
+use Moo 1.004005;
 use MooX::Types::MooseLike::Base qw(AnyOf Bool Enum Maybe);
 use namespace::clean;
 extends 'WWW::Mechanize';
@@ -239,7 +239,7 @@ WWW::Mechanize::Cached - Cache response to be polite
 
 =head1 VERSION
 
-version 1.45
+version 1.46
 
 =head1 SYNOPSIS
 
